==> kreetingkard-0.6.2.tar.gz: kreetingkard-0.6.2/src/kktemplate/kktcategoryitem.h <==
/***************************************************************************
 *   Copyright (C) 2005 by SUZUKI Tasuku                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _KKTCATEGORYITEM_H_
#define _KKTCATEGORYITEM_H_

#include <klistview.h>
#include <qptrlist.h>
#include <qdom.h>

namespace KKTemplate
{
	class KKTItem;
	typedef QPtrList<KKTItem> KKTItemList;

	class KKTCategoryItem : public KListViewItem
	{
		public:
			KKTCategoryItem( KListView* parent, QDomElement elem, QString path );
			KKTCategoryItem( KListViewItem* parent, QDomElement& elem, QString path );
			KKTItemList& list(){ return m_list; }

		private:
			void readData( QDomElement elem );
			QString m_strPath;
			KKTItemList m_list;
	};
}

#endif /* _KKTCATEGORYITEM_H_ */

==> kreetingkard-0.7.1.tar.gz: kreetingkard-0.7.1/src/kktemplate/kktcategoryitem.h <==
/***************************************************************************
 *   Copyright (C) 2005 by SUZUKI Tasuku                                   *
 *   tasuku@linux-life.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef _KKTCATEGORYITEM_H_
#define _KKTCATEGORYITEM_H_

#include <klistview.h>
#include <qptrlist.h>
#include <qdom.h>

namespace KKTemplate
{
	class KKTItem;
	typedef QPtrList<KKTItem> KKTItemList;

	class KKTCategoryItem : public KListViewItem
	{
		public:
			KKTCategoryItem( KListView* parent, QString path );
			KKTCategoryItem( KListViewItem* parent, QString path );
			KKTItemList& list(){ return m_list; }

		private:
			void readMetaData();
			void readChildren();
			QString m_strPath;
			KKTItemList m_list;
	};
}

#endif /* _KKTCATEGORYITEM_H_ */
